/****************************************************************
 * grl-agent.h													*
 *																*
 * This is a customized version of the boilerplate for compiled	*
 * GRL programs. It serves as a convenient interface for		*
 * FlexBot behavior development regardless of whether the GRL	*
 * language is used in development.	It should not be necessary 	*
 * to modify this file in order to develop a FlexBot behavior.	*
 ****************************************************************/

#ifndef GRL_AGENT_H
#define GRL_AGENT_H

#include "BehaviorInterface.h"
#include "stdlib.h"

#define neqP(a,b) (a != b)
#define random_integer(a) ((int)(rand()%a))

class grl_agent {
 public:
  grl_agent();
  virtual void update(int new_ms_clock) = 0;

  // ---- START FLEX-BOT ----

  // Actuator state information
  int rotate;
  int translate;
  int strafe;
  int pitch;
  bool shoot;
  bool duck;
  bool jump;
  bool secondary;
  int weapon;
  bool reload;
  bool use;

  // Actuator functions (for calling from the think function)
  void do_rotation(int);
  void do_translation(int);
  void do_strafe(int);
  void do_pitch(int);
  void do_shoot(bool);
  void do_duck(bool);
  void do_jump(bool);
  void do_secondary(bool);	
  void do_weapon(int);
  void do_reload(bool);
  void do_use(bool);

  // ---- END FLEX-BOT ----

 protected:
  // The GRL run-time system, such as it is.
  void update_grl_timeB(void);
  void before_signal_update(void);
  void after_signal_update(void);

  bool old_clock_valid;
  int ms_clock;
  int old_ms_clock;
  int measured_clock_period;

  // The GRL compiler needs these (sorry).
  int Ui;
  int UUtemp;

};

#endif //GRL_AGENT_H
