/*****************************************************************
 * FlexMonitor.cpp
 * 
 * This file contains the code necessary to write a game montior
 * module for FlexBot. All code for the FlexMonitor module can be
 * placed in this file.
 *
 * If placed in the FlexModule directory within the FlexBot directory,
 * this control module will have its PlayerUpdate() function called
 * called every think cycle by each player. Keep in mind that 
 * calls to this control module are synchronous (blocking), so it is
 * important to make your FlexMonitor module code efficient so as not to
 * adversely impact game performance.
 *****************************************************************/

#include "stdafx.h"
#include <stdio.h>
#include "FlexMonitor.h"

/*****************************************************
 * LISTEN FOR COMMANDS         					     *
 *													 *
 * This function is called when FlexBot allows the	 *
 * command module to check for external commands.	 *
 * This is where the module should do most of its	 *
 * work.											 *
 *****************************************************/
FLEXMONITOR_API void PlayerUpdate(int playerNum, int x, int y, int z, int health, float facing, float pitch, const char * weapon) {
	
	// An example of displaying the update data in a message box
	char isBotString[10] = "";
	if (!IsPlayerBot(playerNum))
		strcpy(isBotString, " not");
	char updateMsg[1000];
	sprintf(updateMsg, "Location is (%d, %d, %d), health is %d, facing in direction %f with pitch %f. The current map is \"%s\". This is a \"%s\" game. This player is%s a bot. The current FlexBot behavior is \"%s\". The player is on team \"%s\". The player is using \"%s\".",
		x, y, z, health, facing, pitch, CurrentMap(), GameType(), isBotString, BotBehaviorName(playerNum), PlayerTeam(playerNum), weapon);
	char playerMsg[500];
	sprintf(playerMsg, "Player %d Update", playerNum);
	MessageBox(NULL, updateMsg, playerMsg, MB_OK);
}

/*****************************************************
 * DLL MAIN                    					     *
 *													 *
 * This function does NOT need to be modified.       *
 * You may use it to execute initialization code     *
 * for your module. It is called when the DLL		 *
 * is initially loaded by FlexBot.                   *
 *****************************************************/
BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
    switch (ul_reason_for_call)
	{
		case DLL_PROCESS_ATTACH:
		case DLL_THREAD_ATTACH:
		case DLL_THREAD_DETACH:
		case DLL_PROCESS_DETACH:
			break;
    }

	// --- Load pointers to functions exported by FlexBot --- //
	
	// Load the DLL
	char errorMsg[1000];
	initialized = FALSE;
	moduleHandle = FALSE;
	moduleHandle = LoadLibrary("FlexBot/dlls/FlexBot.dll");

	// Could the DLL be loaded?
	if (moduleHandle)
	{
		// Load the function pointer for FLEXMONITOR_CurrentMap()
		pfnCurrentMap = (PFN_CURRENT_MAP) GetProcAddress(moduleHandle, "FLEXMONITOR_CurrentMap");
		if (!pfnCurrentMap)
		{
			sprintf(errorMsg, "FlexMonitor: Error loading function FLEXMONITOR_CurrentMap()\n");
			MessageBox(NULL, errorMsg, "FlexMonitor Error", MB_OK);
			return FALSE;
		}
		pfnIsPlayerBot = (PFN_IS_PLAYER_BOT) GetProcAddress(moduleHandle, "FLEXMONITOR_IsPlayerBot");
		if (!pfnIsPlayerBot)
		{
			sprintf(errorMsg, "FlexMonitor: Error loading function FLEXMONITOR_IsPlayerBot()\n");
			MessageBox(NULL, errorMsg, "FlexMonitor Error", MB_OK);
			return FALSE;
		}
		pfnBotBehaviorName = (PFN_BOT_BEHAVIOR_NAME) GetProcAddress(moduleHandle, "FLEXMONITOR_BotBehaviorName");
		if (!pfnBotBehaviorName)
		{
			sprintf(errorMsg, "FlexMonitor: Error loading function FLEXMONITOR_BotBehaviorName()\n");
			MessageBox(NULL, errorMsg, "FlexMonitor Error", MB_OK);
			return FALSE;
		}
		pfnPlayerTeam = (PFN_PLAYER_TEAM) GetProcAddress(moduleHandle, "FLEXMONITOR_PlayerTeam");
		if (!pfnPlayerTeam)
		{
			sprintf(errorMsg, "FlexMonitor: Error loading function FLEXMONITOR_PlayerTeam()\n");
			MessageBox(NULL, errorMsg, "FlexMonitor Error", MB_OK);
			return FALSE;
		}
		pfnGameType = (PFN_GAME_TYPE) GetProcAddress(moduleHandle, "FLEXMONITOR_GameType");
		if (!pfnGameType)
		{
			sprintf(errorMsg, "FlexMonitor: Error loading function FLEXMONITOR_GameType()\n");
			MessageBox(NULL, errorMsg, "FlexMonitor Error", MB_OK);
			return FALSE;
		}
		pfnPlayerName = (PFN_PLAYER_NAME) GetProcAddress(moduleHandle, "FLEXMONITOR_PlayerName");
		if (!pfnPlayerName)
		{
			sprintf(errorMsg, "FlexMonitor: Error loading function FLEXMONITOR_PlayerName()\n");
			MessageBox(NULL, errorMsg, "FlexMonitor Error", MB_OK);
			return FALSE;
		}
		pfnPlayerKills = (PFN_PLAYER_KILLS) GetProcAddress(moduleHandle, "FLEXMONITOR_PlayerKills");
		if (!pfnPlayerKills)
		{
			sprintf(errorMsg, "FlexMonitor: Error loading function FLEXMONITOR_PlayerKills()\n");
			MessageBox(NULL, errorMsg, "FlexMonitor Error", MB_OK);
			return FALSE;
		}
		pfnPlayerDeaths = (PFN_PLAYER_DEATHS) GetProcAddress(moduleHandle, "FLEXMONITOR_PlayerDeaths");
		if (!pfnPlayerDeaths)
		{
			sprintf(errorMsg, "FlexMonitor: Error loading function FLEXMONITOR_PlayerDeaths()\n");
			MessageBox(NULL, errorMsg, "FlexMonitor Error", MB_OK);
			return FALSE;
		}
	}
	else {
		sprintf(errorMsg, "FlexMonitor: Error loading module \"FlexBot/dlls/FlexBot.dll\"\n");
		MessageBox(NULL, errorMsg, "FlexMonitor Error", MB_OK);
		return FALSE;
	}

	// Set initialized to true and return success
	initialized = TRUE;
    return TRUE;
}
