/*****************************************************************
 * FlexStat.cpp
 * 
 * This file contains the code necessary to write a statistical
 * analysis module for FlexBot. All code for the FlexStat module 
 * can be placed in this file.
 *
 * If placed in the FlexStat directory within the FlexBot directory,
 * this module will have the appropriate functions called when
 * statistical changes occur. All statistics are defined and exported
 * by the central FlexBot architecture. Keep in mind that 
 * calls to this module are synchronous (blocking), so it is
 * important to make your FlexStat module code efficient so as not to
 * adversely impact game performance.
 *****************************************************************/

#include "stdafx.h"
#include <stdio.h>
#include "FlexStat.h"

/*****************************************************
 * ADD PLAYER		         					     *
 *													 *
 * This function is called when FlexBot adds a		 *
 * player to the game. The client index of the new	 *
 * player is given as the argument.					 *
 *****************************************************/
FLEXSTAT_API void AddPlayer(int playerNum) {

}

/*****************************************************
 * REMOVE PLAYER		         					 *
 *													 *
 * This function is called when FlexBot removes a	 *
 * player from the game. The client index of the	 *
 * player is given as the argument.					 *
 *****************************************************/
FLEXSTAT_API void RemovePlayer(int playerNum) {

}

/*****************************************************
 * UPDATE PLAYER NAME	         					 *
 *													 *
 * This function is called when a player's name is	 *
 * is changed during the game.						 *
 *****************************************************/
FLEXSTAT_API void UpdatePlayerName(int playerNum, const char * playerName) {

}

/*****************************************************
 * UPDATE PLAYER TEAM	         					 *
 *													 *
 * This function is called when a player's team is	 *
 * changed during the game. It is also called		 *
 * when the player is initially assigned to a team.  *
 *****************************************************/
FLEXSTAT_API void UpdatePlayerTeam(int playerNum, const char * playerTeam) {

}

/*****************************************************
 * UPDATE BOT BEHAVIOR	         					 *
 *													 *
 * This function is called when a bot's behavior	 *
 * module is changed during the game.				 *
 *****************************************************/
FLEXSTAT_API void UpdateBotBehavior(int playerNum, const char * behaviorName) {

}

/*****************************************************
 * GAME START			         					 *
 *													 *
 * This function is called when a game starts. This	 *
 * may be a good place to reset/initialize any		 *
 * statistics-related data structures you have		 *
 * implemented.										 *
 *****************************************************/
FLEXSTAT_API void GameStart() {

}

/*****************************************************
 * UPDATE PLAYER STAT	         					 *
 *													 *
 * This function is called when a player-related	 *
 * statistic changes. Statistical values are		 *
 * represented as strings.							 *
 *****************************************************/
FLEXSTAT_API void UpdatePlayerStat(int playerNum, const char * statName, const char * statValue) {
	char buffer[1000];
	sprintf(buffer, "For player %d, the value of \"%s\" is now \"%s\".", playerNum, statName, statValue);
	MessageBox(NULL, buffer, "Player stat changed...", MB_OK);
}

/*****************************************************
 * UPDATE TEAM STAT	         						 *
 *													 *
 * This function is called when a team-related		 *
 * statistic changes. Statistical values are		 *
 * represented as strings. Team ID's are represented *
 * as strings (the team name).						 *
 *****************************************************/
FLEXSTAT_API void UpdateTeamStat(const char * teamName, const char * statName, const char * statTeam) {

}

/*****************************************************
 * UPDATE GAME STAT	         						 *
 *													 *
 * This function is called when a game-related		 *
 * statistic changes. Statistical values are		 *
 * represented as strings.							 *
 *****************************************************/
FLEXSTAT_API void UpdateGameStat(const char * statName, const char * statValue) {

}

/*****************************************************
 * INIT FLEX-STAT MODULE                    		 *
 *													 *
 * You may use this function to execute				 *
 * initialization code for your module. It is called *
 * when the module is initially loaded by FlexBot.   *
 *****************************************************/
void InitFlexStatModule() {

}
